@@ -1,7 +1,7 @@
 """
 Type annotations for amp service client paginators.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/paginators.html)
+[Open documentation](./paginators.md)
 
 Usage::
 
@@ -22,20 +22,20 @@ from typing import Iterator
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from mypy_boto3_amp.type_defs import ListWorkspacesResponseTypeDef, PaginatorConfigTypeDef
+from .type_defs import ListWorkspacesResponseTypeDef, PaginatorConfigTypeDef
 
 __all__ = ("ListWorkspacesPaginator",)
 
 
 class ListWorkspacesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/amp.html#PrometheusService.Paginator.ListWorkspaces)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/paginators.html#listworkspacespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/amp.html#PrometheusService.Paginator.ListWorkspaces)[Show boto3-stubs documentation](./paginators.md#listworkspacespaginator)
     """
 
     def paginate(
         self, alias: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListWorkspacesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/amp.html#PrometheusService.Paginator.ListWorkspaces.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/paginators.html#listworkspacespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/amp.html#PrometheusService.Paginator.ListWorkspaces.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listworkspacespaginator)
         """
